/*=========================================================================

  Program:   Flow Topology
  Module:    $RCSfile: vtkFlowTopo.h,v $

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkFlowTopo - extract critical points.
// .SECTION Description
// vtkFlowTopo is a filter that extracts ciritcal points of vector data
// degined on the nodes of an unstructured grid.

#ifndef __vtkFlowTopo_h
#define __vtkFlowTopo_h

#include "vtkPolyDataAlgorithm.h"

#include "vtkFloatArray.h"
#include "vtkUnstructuredGrid.h"

#include "vtkFlowTopoConfigure.h"

class vtkDataArray;

class VTK_FlowTopo_EXPORT vtkFlowTopo : public vtkPolyDataAlgorithm
{
public:
  static vtkFlowTopo *New();
  vtkTypeRevisionMacro(vtkFlowTopo, vtkPolyDataAlgorithm);
  void PrintSelf(ostream& os, vtkIndent indent);
  
  vtkSetClampMacro(GlyphRadius, float, 0.0, VTK_FLOAT_MAX);
  vtkGetMacro(GlyphRadius, float);

protected:
  vtkFlowTopo();
  ~vtkFlowTopo();

  // Usual data generation method
  virtual int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

  virtual int FillInputPortInformation(int port, vtkInformation *info);

  float GlyphRadius;

  void generateCross(double posX, double posY, double posZ,
		     vtkPoints *outputPoints, vtkCellArray *outputLines,
		     int &numPoints);

private:
  vtkFlowTopo(const vtkFlowTopo&);  // Not implemented.
  void computeIt(vtkUnstructuredGrid *, vtkFloatArray *, vtkPolyData *);
  void operator=(const vtkFlowTopo&);  // Not implemented.
};

#endif
